<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Code;
use App\Models\User;
use App\Models\UserMedia;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;

class AdminController extends Controller
{

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            if (Auth::check() && (Auth::user()->hasRole('admin') || Auth::user()->hasRole('super admin'))) {
                return $next($request);
            }

            return redirect()->route('user.sms_login');
           // abort(403, 'Access denied');
        });
    }


    public function index()
    {
        $userCount = User::count();
        $imageCount = UserMedia::where('media_type', 'image')->count();
        $unapprovedImages = UserMedia::where('media_type', 'image')
            ->where('media_status', 0)
            ->count();
        $approvedImages = UserMedia::where('media_type', 'image')
            ->where('media_status', 1)
            ->count();
        $remainingCodes = Code::where('code_status', 0)->count();

        return view('admin.dashboard',compact('userCount','imageCount','unapprovedImages','approvedImages','remainingCodes'));
    }
    public function showImageApproved()
    {
        $data = UserMedia::latest()
            ->where('media_type','image')
            ->where('media_status',1)
            ->whereHas('user')
            ->paginate(20);

        return view('admin.media.approved', compact(['data']));
    }
    public function showImageNotApproved()
    {

        $data = UserMedia::latest()
            ->where('media_type','image')
            ->where('media_status',0)
            ->whereHas('user')
            ->paginate(20);

        return view('admin.media.not-approved', compact('data'));
    }

    public function showVideoApproved()
    {
        return view('admin.media.approved', compact([]));
    }
    public function showVideoNotApproved()
    {
        return view('admin.media.approved', compact([]));
    }


    public function changeStatusSingle(Request $request)
    {
        $validated = $request->validate([
            'id' => 'required|integer|exists:user_media,id',
            'status' => 'required|string|in:approved,not-approved',
        ]);
        $status = $validated['status'] === 'approved' ? 1 : 0;
        $media = UserMedia::findOrFail($validated['id']);
        $media->media_status = $status;
        $media->save();
        return response()->json(['success' => true]);
    }


    public function changeStatusGroup(Request $request){
        $validated = $request->validate([
            'media_ids' => 'required|array',
            'media_ids.*' => 'exists:user_media,id',
            'status' => 'required|string|in:approved,not-approved',
        ]);
        $status = $validated['status'] === 'approved' ? 1 : 0;
        $mediaIds = $validated['media_ids'];

        $mediaIds = array_map('intval', explode(',', $mediaIds[0]));
        UserMedia::whereIn('id', $mediaIds)->update(['media_status' => $status]);
        return redirect()->back()->with('success', 'موارد انتخابی با موفقیت بروزرسانی شدند.');
    }
    public function deleteMediaSingle(Request $request){

        $validated = $request->validate([
            'id' => 'required|integer|exists:user_media,id',
        ]);
        $media = UserMedia::findOrFail($validated['id']);

        if ($this->fileExists('public/'.$media->path.'/'.$media->media_source)) {
            Storage::delete('public/'.$media->path.'/'.$media->media_source);
            $media->delete();
            return response()->json(['success' => true]);
        }else{
            return false;
        }
    }


    public function deleteMediaGroup(Request $request)
    {

        $validated = $request->validate([
            'media_ids' => 'required|array',
            'media_ids.*' => 'exists:user_media,id',
        ]);
        $mediaIds = $validated['media_ids'];

        $mediaIds = array_map('intval', explode(',', $mediaIds[0]));
        $mediaItems = UserMedia::whereIn('id', $mediaIds)->get();
        foreach ($mediaItems as $media) {
            if ($this->fileExists('public/'.$media->path.'/'.$media->media_source)) {
                Storage::delete('public/'.$media->path.'/'.$media->media_source);
                $media->delete();
            }
        }
        return redirect()->back()->with('success', 'موارد انتخابی با موفقیت حذف شدند.');
    }
    protected function fileExists(?string $path): bool
    {
        return $path && Storage::exists($path);
    }
}
