<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\City;
use Illuminate\Http\Request;

class CityController extends Controller
{
    public function index()
    {
        $cities = City::latest()->paginate(20);;
        return view('admin.cities.index', compact('cities'));
    }

    public function create()
    {
        return view('admin.cities.create');
    }

    public function store(Request $request)
    {
        // اعتبارسنجی
        $validated = $request->validate([
            'name' => 'required|unique:cities|max:255',
            'name_en' => 'required|unique:cities|max:255',
            'prize_type' => 'required|in:queue,discount_code,custom_sms',
            'custom_sms_text' => 'nullable|string',
        ]);

        $name_en = str_replace(' ', '-', $validated['name_en']);
        City::create([
            'name' => $validated['name'],
            'name_en' => $name_en,
            'prize_type' => $validated['prize_type'],
            'custom_sms_text' => $validated['custom_sms_text'] ?? null,
        ]);

        return redirect()->route('cities.index')->with('success', 'شهر جدید با موفقیت ایجاد شد.');
    }

    public function show(City $city)
    {
        return view('admin.cities.show', compact('city'));
    }

    public function edit(City $city)
    {
        return view('admin.cities.edit', compact('city'));
    }

    public function update(Request $request, City $city)
    {
        // اعتبارسنجی
        $validated = $request->validate([
            'name' => 'required|unique:cities,name,' . $city->id . '|max:255',
            'prize_type' => 'required|in:queue,discount_code,custom_sms',
            'custom_sms_text' => 'nullable|string',
        ]);

        // بروزرسانی شهر
        $city->update([
            'name' => $validated['name'],
            'prize_type' => $validated['prize_type'],
            'custom_sms_text' => $validated['custom_sms_text'] ?? null,
        ]);

        return redirect()->route('cities.index')->with('success', 'شهر با موفقیت ویرایش شد.');
    }

//    public function destroy(City $city)
//    {
//        $city->delete();
//
//        return redirect()->route('cities.index')->with('success', 'City deleted successfully.');
//    }
}
