<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreRoleRequest;
use App\Models\Permission;
use App\Models\Role;

class RoleController extends Controller
{
    public function __construct()
    {
        $this->middleware('can:super admin');
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $roles = Role::latest()->paginate(20);
        return view('admin.roles.index', compact(['roles']));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $permissions = Permission::get();
        return view('admin.roles.create', compact(['permissions']));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(StoreRoleRequest $request)
    {
        $role = new Role();
        $role->name = $request->get('name');
        $role->save();
        $role->permissions()->sync($request->input('permissions', []));
        return back()->with('success', 'نقش با موفقیت ایجاد شد');
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $permissions = Permission::get();
        $role = Role::findOrfail($id);
        $role_permissions = $role->permissions()->pluck('permission_id')->toArray();
        return view('admin.roles.edit', compact(['role', 'role_permissions', 'permissions']));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(StoreRoleRequest $request, string $id)
    {
        $protectedRoles = ['super admin', 'admin', 'content editor'];
        $role = Role::findOrFail($id);
        if (!in_array($role->name, $protectedRoles)) {
            $role->name = $request->get('name');
            $role->save();
        }
        $role->permissions()->sync($request->input('permissions', []));
        return back()->with('success', 'نقش ' . $role->name . ' با موفقیت ویرایش شد');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Role $role)
    {
        $protectedRoles = ['super admin', 'admin', 'content editor'];
        if (in_array($role->name, $protectedRoles)) {
            return back()->withErrors('نقش ' . $role->name . ' قابل حذف نیست');
        }
        $role->permissions()->detach();
        $role->delete();
        return back()->with('success', 'نقش ' . $role->name . ' با موفقیت حذف شد');
    }
}
