<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreUserRequest;
use App\Models\Role;
use App\Models\User;
use Illuminate\Support\Facades\Auth;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        if (auth()->user()->hasRole('super admin')) {
            $users = User::latest()->paginate(20);
            return view('admin.users.index', compact('users'));
        } else {
            abort(503);
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        if (auth()->user()->hasRole('super admin')) {
            $roles = Role::all();
            return view('admin.users.create', compact(['roles']));
        } else {
            abort(503);
        }
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(StoreUserRequest $request)
    {
        if ($request->get('password') == null) {
            return back()->withErrors('فیلد رمز عبور الزامی است');
        }
        if (auth()->user()->hasRole('super admin')) {
            $user = new User();
            $user->name = $request->get('name');
            $user->email = $request->get('email');
            $user->password = bcrypt($request->get('password'));
            $user->save();
            $user->roles()->sync($request->input('roles', []));
            return redirect()->route('users.edit', $user->id)->with('success', 'کاربر با موفقیت ایجاد شد.');
        } else {
            abort(503);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $loggedInUser = Auth::user();
        if ($loggedInUser->hasRole('super admin')) {
            $user = User::findOrFail($id);
        } else {
            $user = $loggedInUser;
        }
        $roles = Role::all();
        $user_roles = $user->roles()->pluck('role_id')->toArray();
        return view('admin.users.edit', compact(['user', 'roles', 'user_roles']));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(StoreUserRequest $request, string $id)
    {
        $loggedInUser = Auth::user();
        if ($loggedInUser->hasRole('super admin')) {
            $user = User::findOrFail($id);
        } else {
            $user = $loggedInUser;
        }
        $user->name = $request->get('name');
        if ($request->get('password') != null) {
            $user->password = bcrypt($request->get('password'));
        }
        $user->save();
        if ($loggedInUser->id != $id) {
            $user->roles()->sync($request->input('roles', []));
        }
        return back()->with('success', 'کاربر ' . $user->name . ' با موفقیت ویرایش شد');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(User $user)
    {
        if (auth()->user()->hasRole('super admin')) {
            $loggedInUser = Auth::user();
            if ($loggedInUser->hasRole('super admin') && $user->id !== $loggedInUser->id) {
                $user->roles()->detach();
                $user->delete();
                return back()->with('success', 'کاربر ' . $user->name . ' با موفقیت حذف شد');
            } else {
                return back()->withErrors('شما مجاز به حذف کاربر نیستید');
            }
        } else {
            abort(503);
        }
    }
}
