<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\VerifySms;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\User;

class UserLoginController extends Controller
{
    protected $username;
    protected $password;
    protected $from;
    protected $pattern_code;

    public function __construct()
    {
        $this->username = env('SMS_USERNAME');
        $this->password = env('SMS_PASSWORD');
        $this->from = env('SMS_FROM');
        $this->pattern_code = env('SMS_PATTERN_CODE');
    }

    public function showSmsLoginForm()
    {

        if (Auth()->user()){

            return redirect()->route('profile');
        }else{
            return view('front.sms-login');
        }

    }

    public function loginWithSms(Request $request)
    {
        if (!Auth()->user()) {
            $request->validate(['phone' => 'required|numeric']);

            if (!$this->checkUser($request->phone)) {
                return response()->json(['success' => false, 'message' => 'کاربر یافت نشد.']);
            }

            $smsCode = rand(10000, 99999);

            $verification = VerifySms::create([
                'phone_number' => $request->phone,
                'sms_code' => $smsCode,
                'verifySms_status' => 0
            ]);

            $smsResponse = $this->sendVerificationCode($request->phone, $smsCode);
            return $smsResponse;
        }
    }
    protected function checkUser($phone_number)
    {
        return User::where('phone_number', $phone_number)->exists();
    }

    protected function sendVerificationCode($phone_number, $rand)
    {
        if (!Auth()->user()) {
        if (!$this->checkUser($phone_number)) {
            return response()->json(['exist' => 0]);
        }


        $username = $this->username;
        $password = $this->password;
        $from = $this->from;
        $pattern_code = $this->pattern_code;
        $to = array($phone_number);
        $input_data = array("verification-code" => $rand);
        $url = "https://ippanel.com/patterns/pattern?username=" . "$username" . "&password=" . urlencode($password) . "&from=" . urlencode($from) . "&to=" . urlencode(json_encode($to)) . "&input_data=" . urlencode(json_encode($input_data)) . "&pattern_code=" . urlencode($pattern_code);
        $handler = curl_init($url);
        curl_setopt($handler, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($handler);

        if (intval($response)){
            return response()->json(['success' => true, 'message' => 'SMS sent successfully!']);
        }else{
            return response()->json(['success' => false, 'message' => 'An error occurred while sending SMS']);
        }
        }
    }


    public function verifySmsCode(Request $request)
    {
        if (!Auth()->user()) {
            $request->validate([
                'phone' => 'required|numeric|digits:11',
                'code' => 'required|numeric',
            ]);

            $verification = VerifySms::where('phone_number', $request->phone)
                ->where('sms_code', $request->code)
                ->where('verifySms_status', 0)
                ->latest()
                ->first();

            if ($verification) {
                $codeCreationTime = $verification->created_at;
                $expirationTime = $codeCreationTime->addMinutes(2);
                if ($expirationTime < now()) {
                    return response()->json(['success' => false, 'message' => 'کد اعتبار سنجی منقضی شده است.']);
                }
                $verification->verifySms_status = 1;
                $verification->save();
                $user = User::firstOrCreate(['phone_number' => $request->phone]);
                Auth::login($user);
                redirect()->route('profile');
                return response()->json(['success' => true, 'message' => 'ورود با موفقیت انجام شد.']);
            }

            return response()->json(['success' => false, 'message' => 'کد نامعتبر است.']);
        }
    }




}
