<?php

namespace App\Http\Controllers;

use App\Models\UserMedia;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use Carbon\Carbon;


class UserMediaController extends Controller
{
    public function index()
    {
        $media = UserMedia::all();
        return view('user_media.index', compact('media'));
    }

    public function create()
    {
        return view('user_media.create');
    }

//    public function store(Request $request)
//    {
//        $request->validate([
//            'user_id' => 'required|exists:users,id',
//            'media_type' => 'required|in:image,video',
//            'media_source' => 'required|string',
//        ]);
//
//        UserMedia::create($request->all());
//
//        return redirect()->route('user_media.index');
//    }

    public function show(UserMedia $userMedia)
    {
        return view('user_media.show', compact('userMedia'));
    }

    public function edit(UserMedia $userMedia)
    {
        return view('user_media.edit', compact('userMedia'));
    }

    public function update(Request $request, UserMedia $userMedia)
    {
        $request->validate([
            'user_id' => 'required|exists:users,id',
            'media_type' => 'required|in:image,video',
            'media_source' => 'required|string',
        ]);

        $userMedia->update($request->all());

        return redirect()->route('user_media.index');
    }

    public function destroy(UserMedia $userMedia)
    {
        $userMedia->delete();
        return redirect()->route('user_media.index');
    }


    public function store(Request $request)
    {

        $request->validate([
            'city' => 'nullable|string|max:255',
            'phone_number' => 'required|string|max:255',
            'image' => 'nullable|mimes:jpeg,png,jpg,gif|max:2048',
            'video' => 'nullable|mimetypes:video/mp4,video/webm|max:5240',
        ]);

        // تعیین نام شهر یا مقدار پیش‌فرض "no-city"
        $cityName = $request->input('city', 'no-city');

        // ایجاد مسیر بر اساس سال و ماه جاری
        $year = Carbon::now()->year;
        $month = Carbon::now()->month;
        $storagePath = "public/{$cityName}/{$year}/{$month}";
        $path = "{$cityName}/{$year}/{$month}";

        // بررسی و ایجاد دایرکتوری در صورت عدم وجود
        if (!Storage::exists($storagePath)) {
            Storage::makeDirectory($storagePath);
        }

        // بررسی وجود کاربر با شماره تلفن
        $user = User::where('phone_number', $request->phone_number)->first();

        // اگر کاربر وجود نداشت، کاربر جدید ایجاد کن
        if (!$user) {
            $user = User::create([
                'name' => $request->input('name'), // می‌توانید نام کاربر را هم از فرم بگیرید
                'phone_number' => $request->phone_number,
            ]);
        }

        // آرایه‌ای برای ذخیره کردن media ها
        $mediaData = [];

        // ذخیره فایل تصویر اگر موجود باشد
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = "user_" . $user->id . "_" . time() . "_image." . $image->getClientOriginalExtension();
            $imagePath = $image->storeAs($storagePath, $imageName, 'local');

            // ذخیره اطلاعات تصویر در آرایه
            $mediaData[] = [
                'user_id' => $user->id,
                'media_type' => 'image',
                'media_source' => $imageName,
                'path' => $path,
                'city_name' => $cityName,
                'media_status' => false,
            ];
        }

        // ذخیره فایل ویدئو اگر موجود باشد
        if ($request->hasFile('video')) {
            $file = $request->file('video');
            $filenameWithExt = $file->getClientOriginalName();
            $filename = pathinfo($filenameWithExt, PATHINFO_FILENAME);
            $extension = 'mp4';
            $fileNameToStore = preg_replace('/\s+/', '_', $filename . '_' . time() . '.' . $extension);

            Storage::disk('local')->putFileAs($storagePath, $file, $fileNameToStore);

            // ذخیره اطلاعات ویدئو در آرایه
            $mediaData[] = [
                'user_id' => $user->id,
                'media_type' => 'video',
                'media_source' => $fileNameToStore,
                'path' => $path,
                'city_name' => $cityName,
                'media_status' => false,
            ];
        }

        foreach ($mediaData as $media) {
            UserMedia::create($media);
        }

        return response()->json([
            'message' => 'Media uploaded successfully',
            'data' => $mediaData
        ], 201);
    }
}
