<?php

namespace App\Providers;

use Illuminate\Pagination\Paginator;
use App\Models\Permission;
use Illuminate\Support\Facades\Gate;
use Illuminate\Support\Facades\Blade;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\ServiceProvider;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register(): void
    {
        //
    }

    /**
     * Bootstrap any application services.
     */
    public function boot(): void
    {
        Schema::defaultStringLength(191);

        Paginator::useBootstrapFive();

        try {
            Permission::get()->map(function ($permission) {
                Gate::define($permission->name, function ($user) use ($permission) {
                    return $user->hasPermissionTo($permission);
                });
            });
        } catch (\Exception $e) {
            report($e);
        }

        // Custom Blade directive to check if the user has a specific role
        Blade::directive('role', function ($role) {
            return "<?php if(auth()->check() && auth()->user()->hasRole({$role})) : ?>";
        });

        // Custom Blade directive to end the role check
        Blade::directive('endrole', function ($role) {
            return "<?php endif; ?>";
        });


        // svg directive
        \Blade::directive('svg', function ($arguments) {
            list($path, $class) = array_pad(explode(',', trim($arguments, "() ")), 2, '');
            $path = trim($path, "' ");
       
            $class = trim($class, "' ");
            $svg = new \DOMDocument();
            $filePath = $path;
            if (file_exists($filePath)) {
         
                $svg->load($filePath);
                $svg->documentElement->setAttribute("class", $class);
                $output = $svg->saveXML($svg->documentElement);
                return $output;
            }
        });
    }
}
