@section('title', 'تایید شده ها')
@extends('admin.main')
@section('content')
    <div class="row">
        <div class="col-md-12 mb-4">
            @include('admin.items.message')
            <div class="card h-100">
                <div class="card-header text-center">
                    <p>تایید شده ها</p>

                </div>
                <div class="row images">
                    @if($data)
                        <div class="d-flex m-3">
                            <!-- Change Status Group Form -->
                            <form action="{{ route('changeStatusGroup') }}" method="POST" id="changeStatusForm" class="mx-1">
                                @csrf
                                <input type="hidden" name="media_ids[]" id="changeStatusMediaIds">
                                <input type="hidden" name="status" value="not-approved">
                                <button class="btn btn-success text-white">
                                    @svg('assets/admin/images/emoji-heart-eyes.svg', 'me-1 text-white')
                                    عدم تایید انتخاب شده ها
                                </button>
                            </form>

                            <form action="{{ route('deleteMediaGroup') }}" method="POST" id="deleteMediaForm" class="mx-1">
                                @csrf
                                <input type="hidden" name="media_ids[]" id="deleteMediaIds">
                                <button class="btn btn-danger">
                                    @svg('assets/admin/images/delete.svg', 'me-1 text-white')
                                    حذف انتخاب شده ها
                                </button>
                            </form>
                        </div>
                    @endif

                    @foreach($data as $value)
                        <div class="col-md-3 media-item" data-id="{{$value->id}}" data-status="not-approved">
                            <div class="card-body m-2">
                                @if($value->media_source)
                                    @if($value->media_type == 'image')
                                        <img class="mb-3 rounded-2"
                                             src="/upload/{{$value->path.'/'.$value->media_source}}"
                                             alt="">
                                    @elseif($value->media_type == 'video')
                                        <video width="290" height="240" controls>
                                            <source src="/upload/{{$value->path.'/'.$value->media_source}}" type="video/mp4">
                                        </video>
                                    @endif
                                @endif
                                <p>نام : {{ $value->user->name}}</p>
                                <p>شماره تماس : {{ $value->user->phone_number}}</p>
                                <p>تاریخ تولد : {{ $value->user->birthday}}</p>
                                <div>
                                    <input name="media_ids[]" class="form-check-input media-checkbox" type="checkbox"
                                           value="{{$value->id}}" id="flexCheckChecked_{{$value->id}}">
                                    @if($value->media_status == '0')
                                        <span role="button" class="change-status">@svg('assets/admin/images/emoji-heart-eyes.svg', 'text-success')</span>
                                    @elseif($value->media_status == '1')
                                        <span role="button" class="change-status">@svg('assets/admin/images/emoji-frown.svg', 'text-danger')</span>
                                    @endif
                                    <span role="button" class="delete-media">@svg('assets/admin/images/delete.svg', 'text-danger')</span>
                                </div>
                            </div>
                        </div>
                    @endforeach
                </div>
                <div class="mx-2 mt-5">{{ $data->links() }}</div>
            </div>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const changeStatusForm = document.getElementById('changeStatusForm');
            const deleteMediaForm = document.getElementById('deleteMediaForm');

            function collectSelectedIds() {
                let selectedIds = [];
                const checkboxes = document.querySelectorAll(`input[name="media_ids[]"]:checked`);
                checkboxes.forEach(checkbox => {
                    selectedIds.push(checkbox.value);
                });
                return selectedIds;
            }

            changeStatusForm.addEventListener('submit', function (e) {
                const selectedIds = collectSelectedIds();
                if (selectedIds.length === 0) {
                    e.preventDefault();
                    alert('لطفاً حداقل یک آیتم انتخاب کنید');
                } else {
                    // Clear the existing values in the hidden input before adding new ones
                    const mediaIdsInput = document.getElementById('changeStatusMediaIds');
                    mediaIdsInput.value = ''; // Clear previous values
                    selectedIds.forEach(id => {
                        mediaIdsInput.value += id + ','; // Add each ID
                    });
                    // Remove the trailing comma
                    mediaIdsInput.value = mediaIdsInput.value.slice(0, -1);
                }
            });

            deleteMediaForm.addEventListener('submit', function (e) {
                const selectedIds = collectSelectedIds();
                if (selectedIds.length === 0) {
                    e.preventDefault();
                    alert('لطفاً حداقل یک آیتم انتخاب کنید');
                } else {
                    // Clear the existing values in the hidden input before adding new ones
                    const mediaIdsInput = document.getElementById('deleteMediaIds');
                    mediaIdsInput.value = ''; // Clear previous values
                    selectedIds.forEach(id => {
                        mediaIdsInput.value += id + ','; // Add each ID
                    });
                    // Remove the trailing comma
                    mediaIdsInput.value = mediaIdsInput.value.slice(0, -1);
                }
            });
        });
    </script>

@endsection
