<?php

use App\Http\Controllers\Admin\AdminController;
use App\Http\Controllers\Admin\CityController;
use App\Http\Controllers\Admin\DiscountCodeController;
use App\Http\Controllers\Admin\PermissionController;
use App\Http\Controllers\Admin\RoleController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\Auth\UserLoginController;
use App\Http\Controllers\Front\PageController as FrontPageControllerAlias;
use App\Http\Controllers\Admin\UserController as AdminUserController;
use App\Http\Controllers\Front\UserController;
use App\Http\Controllers\Front\UserMediaController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/


Auth::routes([
    'register' => false, // Register Routes...
    'reset' => false, // Reset Password Routes...
    'verify' => false, // Email Verification Routes...
]);

Route::get('/login', [LoginController::class, 'showLoginForm'])->name('customer.login');
Route::post('/login', [LoginController::class, 'login']);

Route::get('/', [FrontPageControllerAlias::class, 'home'])->name('home');
Route::get('/capture', [FrontPageControllerAlias::class, 'capture'])->name('capture');
Route::post('/save-capture-media', [FrontPageControllerAlias::class, 'store'])->name('captureMediaStore');
Route::get('/user-login', [UserLoginController::class, 'showSmsLoginForm'])->name('user.sms_login');
Route::post('/user-login', [UserLoginController::class, 'loginWithSms']);
Route::post('/user-login/verify', [UserLoginController::class, 'verifySmsCode'])->name('user.sms_verify');
Route::get('/coupon/{id}', [FrontPageControllerAlias::class, 'showCodeForm']);

Route::group(['middleware' => 'auth'], function () {
    Route::get('/user-profile', [UserController::class, 'userProfile'])->name('profile');
    Route::post('/user-save-information', [UserController::class, 'userSaveInformation'])->name('userSaveInformation');
});


//Route::get('/customer/verify-sms', [CustomerLoginController::class, 'showSmsVerificationForm'])->name('customer.verify.sms');
//Route::post('/customer/verify-sms', [CustomerLoginController::class, 'verifySms']);


Route::group(['middleware' => 'auth', 'super admin'], function () {
    Route::resource('/admin/roles', RoleController::class);
    Route::resource('/admin/permissions', PermissionController::class);

    Route::resource('/admin/users', AdminUserController::class);
    Route::get('/admin', [AdminController::class, 'index'])->name('dashboard');
    Route::get('/admin/api/online-users-count', [AdminController::class, 'getOnlineUsersCount']);


    Route::get('/admin/image-approved', [AdminController::class, 'showImageApproved'])->name('showImageApproved');
    Route::get('/admin/image-not-approved', [AdminController::class, 'showImageNotApproved'])->name('showImageNotApproved');

    Route::get('/admin/video-approved', [AdminController::class, 'showVideoApproved'])->name('showVideoApproved');
    Route::get('/admin/video-not-approved', [AdminController::class, 'showVideoNotApproved'])->name('showVideoNotApproved');

    Route::post('/admin/change-status-single', [AdminController::class, 'changeStatusSingle'])->name('changeStatusSingle');
    Route::post('/admin/change-status-group', [AdminController::class, 'changeStatusGroup'])->name('changeStatusGroup');
    Route::post('/admin/delete-media-single', [AdminController::class, 'deleteMediaSingle'])->name('deleteMediaSingle');
    Route::post('/admin/delete-media-group', [AdminController::class, 'deleteMediaGroup'])->name('deleteMediaGroup');


    Route::resource('/admin/cities', CityController::class);
    Route::get('admin/discount-codes', [DiscountCodeController::class, 'index'])->name('discount-codes.index');
    Route::post('admin/discount-codes/generate', [DiscountCodeController::class, 'generateCodes'])->name('discount-codes.generate');
    Route::get('admin/discount-codes/reset', [DiscountCodeController::class, 'resetCodes'])->name('discount-codes.reset');
    Route::get('admin/view-all-discount-codes', [DiscountCodeController::class, 'viewAllDiscountCodes'])->name('discount-codes.view-all');

});

Route::get('/uploads/{filename}', function ($filename) {
    $filePath = storage_path('app/public/' . $filename);

    if (file_exists($filePath)) {
        return response()->file($filePath);
    }

    return response()->json(['error' => 'File not found'], 404);
});