<?php
use Illuminate\Foundation\Testing\RefreshDatabase;
use Tests\TestCase;
use App\Models\Page;

class PageTest extends TestCase
{
    use RefreshDatabase;

    public function testCreatePage()
    {
        $pageData = [
            'title' => 'Test Page',
            'slug' => 'test-page',
            'content' => 'This is the content of the test page.',
            'parent_id' => null,
            'view_count' => 0,
        ];

        // Create a new page
        $page = Page::create($pageData);

        // Check if the page exists in the database
        $this->assertDatabaseHas('pages', $pageData);

        // Check if the created page has the correct ID
        $this->assertNotNull($page->id);
    }

    public function testRetrievePageBySlug()
    {
        // Create a new page
        $page = Page::create([
            'title' => 'Test Page',
            'slug' => 'test-page',
            'content' => 'This is the content of the test page.',
        ]);

        // Retrieve the page by its slug
        $retrievedPage = Page::findBySlug('test-page');

        // Check if the retrieved page matches the created page
        $this->assertEquals($page->id, $retrievedPage->id);
    }

    public function testUpdatePage()
    {
        // Create a new page
        $page = Page::create([
            'title' => 'Test Page',
            'slug' => 'test-page',
            'content' => 'This is the content of the test page.',
        ]);

        // Update the page's title and content
        $page->update([
            'title' => 'Updated Test Page',
            'content' => 'This is the updated content of the test page.',
        ]);

        // Check if the page was updated in the database
        $this->assertDatabaseHas('pages', [
            'id' => $page->id,
            'title' => 'Updated Test Page',
            'content' => 'This is the updated content of the test page.',
        ]);
    }

    public function testDeletePage()
    {
        // Create a new page
        $page = Page::create([
            'title' => 'Test Page',
            'slug' => 'test-page',
            'content' => 'This is the content of the test page.',
        ]);

        // Delete the page
        $page->delete();

        // Check if the page was deleted from the database
        $this->assertDatabaseMissing('pages', ['id' => $page->id]);
    }
}
